@@ -75,11 +75,11 @@
 	 relay_ip = {127,0,0,1}      :: inet:ip_address(),
 	 min_port = 49152            :: non_neg_integer(),
 	 max_port = 65535            :: non_neg_integer(),
-	 max_allocs = 10             :: non_neg_integer() | unlimited,
+	 max_allocs = 10             :: non_neg_integer() | infinity,
 	 shaper = none               :: stun_shaper:shaper(),
-	 max_permissions = 10        :: non_neg_integer() | unlimited,
+	 max_permissions = 10        :: non_neg_integer() | infinity,
 	 auth = user                 :: anonymous | user,
-	 nonces = stun_treap:empty() :: stun_treap:treap(),
+	 nonces = treap:empty()      :: treap:treap(),
 	 realm = <<"">>              :: binary(),
 	 auth_fun                    :: function(),
 	 server_name = ?SERVER_NAME  :: binary(),
@@ -587,13 +587,13 @@ now_priority() ->
     -((MSec*1000000 + Sec)*1000000 + USec).
 
 clean_treap(Treap, CleanPriority) ->
-    case stun_treap:is_empty(Treap) of
+    case treap:is_empty(Treap) of
 	true ->
 	    Treap;
 	false ->
-	    {_Key, Priority, _Value} = stun_treap:get_root(Treap),
+	    {_Key, Priority, _Value} = treap:get_root(Treap),
 	    if Priority > CleanPriority ->
-		    clean_treap(stun_treap:delete_root(Treap), CleanPriority);
+		    clean_treap(treap:delete_root(Treap), CleanPriority);
 	       true ->
 		    Treap
 	    end
@@ -601,14 +601,14 @@ clean_treap(Treap, CleanPriority) ->
 
 make_nonce(Addr, Nonces) ->
     Priority = now_priority(),
-    Nonce = erlang:integer_to_binary(random:uniform(1 bsl 32)),
+    Nonce = list_to_binary(integer_to_list(random:uniform(1 bsl 32))),
     NewNonces = clean_treap(Nonces, Priority + ?NONCE_LIFETIME),
-    {Nonce, stun_treap:insert(Nonce, Priority, Addr, NewNonces)}.
+    {Nonce, treap:insert(Nonce, Priority, Addr, NewNonces)}.
 
 have_nonce(Nonce, Nonces) ->
     Priority = now_priority(),
     NewNonces = clean_treap(Nonces, Priority + ?NONCE_LIFETIME),
-    case stun_treap:lookup(Nonce, NewNonces) of
+    case treap:lookup(Nonce, NewNonces) of
 	{ok, _, _} ->
 	    {true, NewNonces};
 	_ ->
